==> rendition-9.4.0.tgz: package/dist_esm5/components/DataTypes/date-time.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Input from '../Input';
import { getDefaultDate, normalizeDateTime } from './date-time-helpers';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_before: {
        getLabel: function (_s) { return 'is before'; },
    },
    is_after: {
        getLabel: function (_s) { return 'is after'; },
    },
};
export var decodeFilter = function (filter) {
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var field = keys[0];
    var operator = filter.title;
    var value;
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_before') {
        value = filter.properties[field].formatMaximum;
    }
    else if (operator === 'is_after') {
        value = filter.properties[field].formatMinimum;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + value,
        type: 'object',
    };
    var normalizedValue = normalizeDateTime(value);
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'string',
                    format: 'date-time',
                    const: normalizedValue,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_before') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'string',
                    format: 'date-time',
                    formatMaximum: normalizedValue,
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'is_after') {
        return assign(base, {
            properties: (_c = {},
                _c[field] = {
                    type: 'string',
                    format: 'date-time',
                    formatMinimum: normalizedValue,
                },
                _c),
            required: [field],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var value = _a.value, onUpdate = _a.onUpdate, props = tslib_1.__rest(_a, ["value", "onUpdate"]);
    if (!value) {
        onUpdate(getDefaultDate());
    }
    return (React.createElement(Input, tslib_1.__assign({}, props, { type: "datetime-local", value: value, onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } })));
};

==> rendition-11.13.0.tgz: package/dist_esm5/components/DataTypes/date-time.js <==
import { __assign, __rest } from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Input from '../Input';
import { getDefaultDate, normalizeDateTime } from './date-time-helpers';
import { getJsonDescription } from './utils';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_before: {
        getLabel: function (_s) { return 'is before'; },
    },
    is_after: {
        getLabel: function (_s) { return 'is after'; },
    },
};
export var decodeFilter = function (filter) {
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var field = keys[0];
    var operator = filter.title;
    var value;
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_before') {
        value = filter.properties[field].formatMaximum;
    }
    else if (operator === 'is_after') {
        value = filter.properties[field].formatMinimum;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: getJsonDescription(title || field, operators[operator].getLabel(schema), value),
        type: 'object',
    };
    var normalizedValue = normalizeDateTime(value);
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'string',
                    format: 'date-time',
                    const: normalizedValue,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_before') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'string',
                    format: 'date-time',
                    formatMaximum: normalizedValue,
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'is_after') {
        return assign(base, {
            properties: (_c = {},
                _c[field] = {
                    type: 'string',
                    format: 'date-time',
                    formatMinimum: normalizedValue,
                },
                _c),
            required: [field],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var value = _a.value, onUpdate = _a.onUpdate, props = __rest(_a, ["value", "onUpdate"]);
    if (!value) {
        onUpdate(getDefaultDate());
    }
    return (React.createElement(Input, __assign({}, props, { type: "datetime-local", value: value, onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } })));
};
